@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -45,13 +45,13 @@ class Horde_Exception_ExceptionTest extends  PHPUnit_Framework_TestCase
     public function testMethodTostringYieldsExceptionDescription()
     {
         $e = new Horde_Exception();
-        $this->assertContains('exception \'Horde_Exception\'', (string)$e);
+        $this->assertRegexp('/(exception |^)\'?Horde_Exception\'? in/', (string)$e);
     }
 
     public function testMethodTostringContainsDescriptionOfPreviousException()
     {
         $e = new Horde_Exception(null, null, new Exception('previous'));
-        $this->assertContains('Next exception \'Horde_Exception\'', (string)$e);
+        $this->assertRegexp('/Next( exception)? \'?Horde_Exception\'?/', (string)$e);
     }
 
     // NotFound Exception Testing
